<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Service Contract - {{ customer_name }}</title>
    <style>
        body {
            font-family: "Times New Roman", Times, serif;
            line-height: 1.5;
            color: #000;
            max-width: 8.5in;
            margin: 0 auto;
            padding: 0.5in;
        }
        .header {
            text-align: center;
            margin-bottom: 2em;
            border-bottom: 1px solid #000;
            padding-bottom: 1em;
        }
        .title {
            font-size: 18pt;
            font-weight: bold;
            margin-bottom: 0.5em;
            text-transform: uppercase;
        }
        .contract-info {
            font-size: 12pt;
            margin: 1em 0;
        }
        .section {
            margin-top: 1.5em;
            margin-bottom: 1.5em;
        }
        .section-title {
            font-size: 14pt;
            font-weight: bold;
            margin-bottom: 0.5em;
        }
        .section-content {
            font-size: 12pt;
            text-align: justify;
        }
        .numbered-section {
            margin-left: 0.5em;
        }
        .signatures {
            margin-top: 3em;
            page-break-inside: avoid;
        }
        .signature-block {
            margin-bottom: 2em;
        }
        .signature-line {
            border-top: 1px solid #000;
            width: 80%;
            margin-top: 3em;
        }
        .footer {
            margin-top: 2em;
            padding-top: 1em;
            border-top: 1px solid #eee;
            font-size: 10pt;
            color: #666;
            text-align: center;
        }
    </style>
</head>
<body>
    <div class="header">
        <div class="title">Service Contract</div>
        <div class="contract-info">Contract #: {{ contract_number }}</div>
    </div>
    
    <div class="section">
        <p>This Service Contract (the "Contract") is entered into as of {{ effective_date }} (the "Effective Date") by and between:</p>
        
        <p><strong>Service Provider:</strong> Our Company, with its principal place of business at 123 Business St, Business City, BS 12345</p>
        
        <p><strong>Client:</strong> {{ customer_name }}, with its principal place of business at {{ customer_address }}</p>
    </div>
    
    <div class="section">
        <div class="section-title">1. SERVICES</div>
        <div class="section-content numbered-section">
            <p>The Service Provider agrees to provide to the Client the services described below (collectively, the "Services"):</p>
            <p>{{ service_description }}</p>
        </div>
    </div>
    
    <div class="section">
        <div class="section-title">2. TERM</div>
        <div class="section-content numbered-section">
            <p>This Contract shall commence on the Effective Date and continue until {{ expiration_date }} (the "Term"), unless earlier terminated as provided herein.</p>
        </div>
    </div>
    
    <div class="section">
        <div class="section-title">3. COMPENSATION</div>
        <div class="section-content numbered-section">
            <p>In consideration for the Services, the Client shall pay the Service Provider a total fee of ${{ contract_value }}.</p>
            <p>{{ payment_terms }}</p>
        </div>
    </div>
    
    <div class="section">
        <div class="section-title">4. RENEWAL</div>
        <div class="section-content numbered-section">
            <p>{{ renewal_terms }}</p>
        </div>
    </div>
    
    <div class="section">
        <div class="section-title">5. LEGAL TERMS</div>
        <div class="section-content numbered-section">
            <p>{{ legal_terms }}</p>
        </div>
    </div>
    
    <div class="signatures">
        <p>IN WITNESS WHEREOF, the parties hereto have executed this Contract as of the Effective Date first above written.</p>
        
        <div class="signature-block">
            <p><strong>Service Provider:</strong></p>
            <div class="signature-line"></div>
            <p>Name: ________________________</p>
            <p>Title: ________________________</p>
            <p>Date: ________________________</p>
        </div>
        
        <div class="signature-block">
            <p><strong>Client: {{ customer_name }}</strong></p>
            <div class="signature-line"></div>
            <p>Name: ________________________</p>
            <p>Title: ________________________</p>
            <p>Date: ________________________</p>
        </div>
    </div>
    
    <div class="footer">
        Contract #{{ contract_number }} | Effective: {{ effective_date }} | Expires: {{ expiration_date }}
    </div>
</body>
</html>
